@@ -1,3 +1,4 @@
+//! Firework Project
 extern crate inkwell_llvm12 as inkwell;
 
 use indoc::formatdoc;
@@ -7,24 +8,29 @@ use std::io::BufRead;
 use std::io::BufReader;
 
 use crate::codegen::CodeGen;
-use crate::parser::ast::parse;
+use crate::parser::parse;
 use crate::unrecoverable_error;
 
+/// Represents a Firework project
 pub struct FireworkProject<'ctx> {
+    /// Compiler used to compile the code of the current Firework project
     compiler: CodeGen<'ctx>,
 }
 
 #[allow(dead_code)]
 impl<'ctx> FireworkProject<'ctx> {
+    /// Instatiates a new ```FireworkProject``` struct
     pub fn new(compiler: CodeGen<'ctx>) -> Self {
         Self { compiler }
     }
 
+    /// Creates a new project
     pub fn new_project(&self, project_name: &str) {
         self.create_project(project_name)
             .unwrap_or_else(|err| unrecoverable_error!(err.to_string()));
     }
 
+    /// Compiles the current project's code
     pub fn compile(&self) -> std::io::Result<()> {
         let main = fs::read_to_string("src/main.firework").unwrap_or_else(|_| {
             unrecoverable_error!("Couldn't read src/main.firework or project not found")
@@ -51,17 +57,17 @@ impl<'ctx> FireworkProject<'ctx> {
                 .map(|(_, line)| line.unwrap())
                 .collect::<String>();
 
-            unrecoverable_error!(formatdoc!(
-                "Syntax error at src/main.firework:{line_number}:{col}
+            unrecoverable_error!(formatdoc! {
+            "Syntax error at src/main.firework:{line_number}:{col}
                 {empty_space}| 
                 {empty_space}| {line}
                 {empty_space}|
                 ",
-                line_number = col.0,
-                col = location,
-                line = line,
-                empty_space = "  ",
-            ));
+            line_number = col.0,
+            col = location,
+            line = line,
+            empty_space = "  ",
+            });
         });
 
         self.compiler.compile(parsed);
@@ -69,6 +75,7 @@ impl<'ctx> FireworkProject<'ctx> {
         Ok(())
     }
 
+    /// Runs the current project's code
     pub fn run(&self) -> Result<(), Box<dyn std::error::Error>> {
         self.compile()?;
         unsafe {
@@ -77,24 +84,27 @@ impl<'ctx> FireworkProject<'ctx> {
         Ok(())
     }
 
+    /// Creates a new Firework project
     fn create_project(&self, project_name: &str) -> std::io::Result<()> {
         fs::create_dir_all(project_name)?;
 
-        fs::write(format!("{}/.gitignore", project_name), "ast.json\nir.ll")?;
+        fs::write(format!("{}/.gitignore", project_name), "ir.ll\nout.asm")?;
         fs::create_dir_all(format!("{}/src", project_name))?;
         fs::write(
             format!("{}/src/main.firework", project_name),
-            "let main: i64 = printf \"Hello World!\n\"",
+            "let main: i64 = printf \"Hello World!\"",
         )?;
 
         Ok(())
     }
 
+    /// Dumps the code of the current project as LLVM IR
     pub fn dump_ir(&self) -> Result<(), LLVMString> {
         self.compile().unwrap();
         self.compiler.dump_ir()
     }
 
+    /// Dumps the code of the current project as AT&T Assembly
     pub fn dump_asm(&self) -> Result<(), LLVMString> {
         self.compile().unwrap();
         self.compiler.dump_asm()
